:github_url: https://github.com/stephane-caron/pink/tree/main/doc/src/limits.rst

.. _Limits:

******
Limits
******

.. automodule:: pink.limits
    :members:

Configuration limits
====================

.. automodule:: pink.limits.configuration_limit
   :members:

Velocity limits
===============

.. automodule:: pink.limits.velocity_limit
   :members:
